@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 ###########################################################################
 
 { package Language::MuldisD; # package
-    use version; our $VERSION = qv('0.19.0');
+    use version; our $VERSION = qv('0.19.1');
     # Note that Perl code only exists at all in this file in order to help
     # the CPAN indexer handle the distribution properly.
 } # package Language::MuldisD
@@ -29,7 +29,7 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Language::MuldisD version 0.19.0.
+This document is Language::MuldisD version 0.19.1.
 
 =head1 PREFACE
 
@@ -37,7 +37,8 @@ This is the root document of the Muldis D language specification; the
 documents that comprise the remaining parts of the specification, in their
 suggested reading order (but that all follow the root), are:
 L<Language::MuldisD::Basics>, L<Language::MuldisD::Core>,
-L<Language::MuldisD::Grammar>, L<Language::MuldisD::PerlHosted>,
+L<Language::MuldisD::Dialect::PTMD_Tiny>,
+L<Language::MuldisD::Dialect::HDMD_Perl_Tiny>,
 L<Language::MuldisD::Hierarchical>, L<Language::MuldisD::Conventions>,
 L<Language::MuldisD::Ext::Temporal>, L<Language::MuldisD::Ext::Spatial>.
 
@@ -52,9 +53,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<MuldisD:'cpan:DUNCAND':'0.19.0'>.  It is the official/original (not
+C<MuldisD:'cpan:DUNCAND':'0.19.1'>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Darren Duncan (C<cpan:DUNCAND>), version C<0.19.0> (this number matches the
+Darren Duncan (C<cpan:DUNCAND>), version C<0.19.1> (this number matches the
 VERSION pod in this file).  This multi-part document is named and organized
 with the expectation that many dialects, extensions, and core versions of
 it will exist over time, some of those under the original author's control,
@@ -246,8 +247,10 @@ dialect needs to be translatable to a standard dialect without changing
 the code's behavior.
 
 See the following parts of the current multi-document for descriptions of
-bundled dialects (subject to change): L<Language::MuldisD::Grammar>,
-L<Language::MuldisD::PerlHosted>, L<Language::MuldisD::Hierarchical>.
+bundled dialects (subject to change):
+L<Language::MuldisD::Dialect::PTMD_Tiny>,
+L<Language::MuldisD::Dialect::HDMD_Perl_Tiny>,
+L<Language::MuldisD::Hierarchical>.
 
 =head2 Extensions
 
